pub struct SandboxRestrictions {
pub max_tokens: usize,
pub max_files: usize,
pub max_tool_results: usize,
pub allowed_tools: Option<HashSet<String>>,
pub denied_tools: Option<HashSet<String>>,
}Expand description
Resource restrictions for a sandbox
Fields
max_tokens: usizeMaximum tokens allowed in the sandbox
max_files: usizeMaximum number of files that can be accessed
max_tool_results: usizeMaximum number of tool results that can be stored
allowed_tools: Option<HashSet<String>>Set of tools that are explicitly allowed (if Some, only these tools are allowed)
denied_tools: Option<HashSet<String>>Set of tools that are explicitly denied (checked after allowed_tools)
Implementations
Sourceimpl SandboxRestrictions
impl SandboxRestrictions
Sourcepub fn new(max_tokens: usize, max_files: usize, max_tool_results: usize) -> Self
pub fn new(max_tokens: usize, max_files: usize, max_tool_results: usize) -> Self
Create restrictions with custom limits
Sourcepub fn with_allowed_tools(
self,
tools: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_allowed_tools( self, tools: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Set allowed tools (whitelist)
Sourcepub fn with_denied_tools(
self,
tools: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_denied_tools( self, tools: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Set denied tools (blacklist)
Sourcepub fn is_tool_allowed(&self, tool_name: &str) -> bool
pub fn is_tool_allowed(&self, tool_name: &str) -> bool
Check if a tool is allowed based on the restrictions
Sourcepub fn check_limits(
&self,
usage: &ResourceUsage,
) -> Option<ResourceLimitViolation>
pub fn check_limits( &self, usage: &ResourceUsage, ) -> Option<ResourceLimitViolation>
Check if resource usage exceeds any limit