pub struct SandboxedContext {
pub sandbox_id: String,
pub agent_id: String,
pub context: AgentContext,
pub restrictions: SandboxRestrictions,
pub state: SandboxState,
pub created_at: DateTime<Utc>,
pub expires_at: Option<DateTime<Utc>>,
pub resources: ResourceUsage,
pub suspension_reason: Option<String>,
}Expand description
A sandboxed context with resource limits and state management
Fields
sandbox_id: StringUnique sandbox identifier
agent_id: StringAssociated agent ID
context: AgentContextThe isolated context
restrictions: SandboxRestrictionsResource restrictions
state: SandboxStateCurrent sandbox state
created_at: DateTime<Utc>Creation timestamp
expires_at: Option<DateTime<Utc>>Expiration timestamp (if set)
resources: ResourceUsageCurrent resource usage
suspension_reason: Option<String>Reason for suspension (if suspended)
Implementations
Sourceimpl SandboxedContext
impl SandboxedContext
Sourcepub fn new(
context: AgentContext,
agent_id: impl Into<String>,
restrictions: Option<SandboxRestrictions>,
) -> Self
pub fn new( context: AgentContext, agent_id: impl Into<String>, restrictions: Option<SandboxRestrictions>, ) -> Self
Create a new sandboxed context
Sourcepub fn with_expiration(self, expires_at: DateTime<Utc>) -> Self
pub fn with_expiration(self, expires_at: DateTime<Utc>) -> Self
Set expiration time
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check if the sandbox has expired
Sourcepub fn is_tool_allowed(&self, tool_name: &str) -> bool
pub fn is_tool_allowed(&self, tool_name: &str) -> bool
Check if a tool is allowed in this sandbox
Sourcepub fn check_limits(&self) -> Option<ResourceLimitViolation>
pub fn check_limits(&self) -> Option<ResourceLimitViolation>
Check resource limits and return violation if any
Sourcepub fn record_tokens(&mut self, count: usize) -> AgentContextResult<()>
pub fn record_tokens(&mut self, count: usize) -> AgentContextResult<()>
Record token usage and check limits
Sourcepub fn record_file_access(&mut self) -> AgentContextResult<()>
pub fn record_file_access(&mut self) -> AgentContextResult<()>
Record file access and check limits
Sourcepub fn record_tool_result(&mut self) -> AgentContextResult<()>
pub fn record_tool_result(&mut self) -> AgentContextResult<()>
Record tool result and check limits