pub enum ExtensionConfig {
Sse {
name: String,
description: String,
uri: Option<String>,
},
Stdio {
name: String,
description: String,
cmd: String,
args: Vec<String>,
envs: Envs,
env_keys: Vec<String>,
timeout: Option<u64>,
bundled: Option<bool>,
available_tools: Vec<String>,
},
Builtin {
name: String,
description: String,
display_name: Option<String>,
timeout: Option<u64>,
bundled: Option<bool>,
available_tools: Vec<String>,
},
Platform {
name: String,
description: String,
bundled: Option<bool>,
available_tools: Vec<String>,
},
StreamableHttp {
name: String,
description: String,
uri: String,
envs: Envs,
env_keys: Vec<String>,
headers: HashMap<String, String>,
timeout: Option<u64>,
bundled: Option<bool>,
available_tools: Vec<String>,
},
Frontend {
name: String,
description: String,
tools: Vec<Tool>,
instructions: Option<String>,
bundled: Option<bool>,
available_tools: Vec<String>,
},
InlinePython {
name: String,
description: String,
code: String,
timeout: Option<u64>,
dependencies: Option<Vec<String>>,
available_tools: Vec<String>,
},
}Expand description
Represents the different types of MCP extensions that can be added to the manager
Variants
Sse
SSE transport is no longer supported - kept only for config file compatibility
Stdio
Standard I/O client with command and arguments
Fields
Builtin
Built-in extension that is part of the bundled aster MCP server
Fields
Platform
Platform extensions that have direct access to the agent etc and run in the agent process
Fields
StreamableHttp
Streamable HTTP client with a URI endpoint using MCP Streamable HTTP specification
Fields
Frontend
Frontend-provided tools that will be called through the frontend
Fields
InlinePython
Inline Python code that will be executed using uvx
Implementations
Sourceimpl ExtensionConfig
impl ExtensionConfig
pub fn streamable_http<S: Into<String>, T: Into<u64>>( name: S, uri: S, description: S, timeout: T, ) -> Self
pub fn stdio<S: Into<String>, T: Into<u64>>( name: S, cmd: S, description: S, timeout: T, ) -> Self
pub fn inline_python<S: Into<String>, T: Into<u64>>( name: S, code: S, description: S, timeout: T, ) -> Self
pub fn with_args<I, S>(self, args: I) -> Self
pub fn key(&self) -> String
Sourcepub fn is_tool_available(&self, tool_name: &str) -> bool
pub fn is_tool_available(&self, tool_name: &str) -> bool
Check if a tool should be available to the LLM