Module aster_apps

Module aster_apps 

aster Apps module

This module contains types and utilities for working with aster Apps, which are UI resources that can be rendered in an MCP server or native aster apps, or something in between.

Re-exports

pub use resource::CspMetadata;
pub use resource::McpAppResource;
pub use resource::ResourceMetadata;
pub use resource::UiMetadata;

Modules

resource