pub enum MessageContent {
Text(TextContent),
Image(ImageContent),
ToolRequest(ToolRequest),
ToolResponse(ToolResponse),
ToolConfirmationRequest(ToolConfirmationRequest),
ActionRequired(ActionRequired),
FrontendToolRequest(FrontendToolRequest),
Thinking(ThinkingContent),
RedactedThinking(RedactedThinkingContent),
SystemNotification(SystemNotificationContent),
}Expand description
Content passed inside a message, which can be both simple content and tool content
Variants
Text(TextContent)
Image(ImageContent)
ToolRequest(ToolRequest)
ToolResponse(ToolResponse)
ToolConfirmationRequest(ToolConfirmationRequest)
ActionRequired(ActionRequired)
FrontendToolRequest(FrontendToolRequest)
Thinking(ThinkingContent)
RedactedThinking(RedactedThinkingContent)
SystemNotification(SystemNotificationContent)
Implementations
Sourceimpl MessageContent
impl MessageContent
pub fn text<S: Into<String>>(text: S) -> Self
pub fn image<S: Into<String>, T: Into<String>>(data: S, mime_type: T) -> Self
pub fn tool_request<S: Into<String>>( id: S, tool_call: ToolResult<CallToolRequestParam>, ) -> Self
pub fn tool_request_with_metadata<S: Into<String>>( id: S, tool_call: ToolResult<CallToolRequestParam>, metadata: Option<&ProviderMetadata>, ) -> Self
pub fn tool_response<S: Into<String>>( id: S, tool_result: ToolResult<CallToolResult>, ) -> Self
pub fn tool_response_with_metadata<S: Into<String>>( id: S, tool_result: ToolResult<CallToolResult>, metadata: Option<&ProviderMetadata>, ) -> Self
pub fn action_required<S: Into<String>>( id: S, tool_name: String, arguments: JsonObject, prompt: Option<String>, ) -> Self
pub fn action_required_elicitation<S: Into<String>>( id: S, message: String, requested_schema: Value, ) -> Self
pub fn action_required_elicitation_response<S: Into<String>>( id: S, user_data: Value, ) -> Self
pub fn thinking<S1: Into<String>, S2: Into<String>>( thinking: S1, signature: S2, ) -> Self
pub fn redacted_thinking<S: Into<String>>(data: S) -> Self
pub fn frontend_tool_request<S: Into<String>>( id: S, tool_call: ToolResult<CallToolRequestParam>, ) -> Self
pub fn system_notification<S: Into<String>>( notification_type: SystemNotificationType, msg: S, ) -> Self
pub fn as_system_notification(&self) -> Option<&SystemNotificationContent>
pub fn as_tool_request(&self) -> Option<&ToolRequest>
pub fn as_tool_response(&self) -> Option<&ToolResponse>
pub fn as_action_required(&self) -> Option<&ActionRequired>
pub fn as_tool_response_text(&self) -> Option<String>
Sourcepub fn as_thinking(&self) -> Option<&ThinkingContent>
pub fn as_thinking(&self) -> Option<&ThinkingContent>
Get the thinking content if this is a ThinkingContent variant
Sourcepub fn as_redacted_thinking(&self) -> Option<&RedactedThinkingContent>
pub fn as_redacted_thinking(&self) -> Option<&RedactedThinkingContent>
Get the redacted thinking content if this is a RedactedThinkingContent variant