pub struct MessageMetadata {
pub user_visible: bool,
pub agent_visible: bool,
}Expand description
Metadata for message visibility
Fields
user_visible: boolWhether the message should be visible to the user in the UI
agent_visible: boolWhether the message should be included in the agent’s context window
Implementations
Sourceimpl MessageMetadata
impl MessageMetadata
Sourcepub fn agent_only() -> Self
pub fn agent_only() -> Self
Create metadata for messages visible only to the agent
Sourcepub fn invisible() -> Self
pub fn invisible() -> Self
Create metadata for messages visible to neither user nor agent (archived)
Sourcepub fn with_agent_invisible(self) -> Self
pub fn with_agent_invisible(self) -> Self
Return a copy with agent_visible set to false
Sourcepub fn with_user_invisible(self) -> Self
pub fn with_user_invisible(self) -> Self
Return a copy with user_visible set to false
Sourcepub fn with_agent_visible(self) -> Self
pub fn with_agent_visible(self) -> Self
Return a copy with agent_visible set to true
Sourcepub fn with_user_visible(self) -> Self
pub fn with_user_visible(self) -> Self
Return a copy with user_visible set to true