InternalHookAction

Enum InternalHookAction 

pub enum InternalHookAction {
Show 17 variants Start, Stop, Error, Bootstrap, Create, Resume, End, Compact, Before, After, New, Reset, Status, Help, Connect, Disconnect, Message,
}
内部钩子事件动作

定义各种事件类型下的具体动作。不同的事件类型有不同的有效动作:

事件类型有效动作
AgentStart, Stop, Error, Bootstrap
SessionCreate, Resume, End, Compact
ToolBefore, After, Error
CommandNew, Reset, Status, Help
GatewayConnect, Disconnect, Message

序列化

序列化时使用小写格式(如 "start""create")。

示例

use aster::hooks::internal::InternalHookAction;

let action = InternalHookAction::Start;
assert_eq!(action.to_string(), "start");

// 序列化为 JSON
let json = serde_json::to_string(&action).unwrap();
assert_eq!(json, "\"start\"");

Variants



Start

Agent 启动

当 Agent 开始运行时触发。



Stop

Agent 停止

当 Agent 停止运行时触发。



Error

Agent 错误

当 Agent 发生错误时触发。也可用于 Tool 错误事件。



Bootstrap

Agent 引导完成

当 Agent 完成初始化引导时触发。



Create

Session 创建

当新会话创建时触发。



Resume

Session 恢复

当会话从持久化状态恢复时触发。



End

Session 结束

当会话结束时触发。



Compact

Session 压缩

当会话历史被压缩时触发。



Before

Tool 执行前

在工具执行之前触发。



After

Tool 执行后

在工具执行之后触发。



New

/new 命令

当用户执行 /new 命令时触发。



Reset

/reset 命令

当用户执行 /reset 命令时触发。



Status

/status 命令

当用户执行 /status 命令时触发。



Help

/help 命令

当用户执行 /help 命令时触发。



Connect

Gateway 连接

当网关建立连接时触发。



Disconnect

Gateway 断开

当网关断开连接时触发。



Message

Gateway 消息

当网关收到或发送消息时触发。