Struct aster::mac::MacBuilder [] [src]

pub struct MacBuilder<F = Identity> { /* fields omitted */ }

A Builder for macro invocations.

Note that there are no commas added between args, as otherwise that macro invocations that could be expressed would be limited. You will need to add all required symbols with with_arg or with_argss.

Methods

impl MacBuilder
[src]

impl<F> MacBuilder<F> where F: Invoke<Mac>
[src]