McpError

Enum McpError 

pub enum McpError {
Show 13 variants Connection { code: i32, message: String, source: Option<Box<dyn Error + Send + Sync>>, }, Transport { code: i32, message: String, source: Option<Box<dyn Error + Send + Sync>>, }, Protocol { code: i32, message: String, }, Timeout { code: i32, message: String, duration: Duration, }, Cancelled { code: i32, message: String, reason: Option<String>, }, Server { code: i32, message: String, data: Option<Value>, }, Validation { code: i32, message: String, errors: Vec<String>, }, Config { code: i32, message: String, source: Option<Box<dyn Error + Send + Sync>>, }, Io { code: i32, message: String, source: Error, }, Serialization { code: i32, message: String, source: Error, }, Lifecycle { code: i32, message: String, server_name: Option<String>, }, Tool { code: i32, message: String, tool_name: Option<String>, }, PermissionDenied { code: i32, message: String, tool_name: Option<String>, },
}
MCP Error type with structured code and message.

All MCP operation failures return this error type, which contains:

  • A numeric error code (following JSON-RPC 2.0 conventions)
  • A human-readable error message
  • Optional additional data

This satisfies Requirement 8.1: “WHEN an MCP operation fails THEN the System SHALL return a structured error with code and message”

Variants



Connection

Connection-related errors (establishing, maintaining connections)

Fields

code: i32

Error code

message: String

Human-readable error message

source: Option<Box<dyn Error + Send + Sync>>

Optional source error



Transport

Transport layer errors (stdio, HTTP, WebSocket communication)

Fields

code: i32

Error code

message: String

Human-readable error message

source: Option<Box<dyn Error + Send + Sync>>

Optional source error



Protocol

Protocol errors (handshake, version negotiation, message format)

Fields

code: i32

Error code

message: String

Human-readable error message



Timeout

Request timeout

Fields

code: i32

Error code

message: String

Human-readable error message

duration: Duration

Duration before timeout occurred



Cancelled

Operation was cancelled

Fields

code: i32

Error code

message: String

Human-readable error message

reason: Option<String>

Optional reason for cancellation



Server

Server returned an error

Fields

code: i32

Error code from server

message: String

Error message from server

data: Option<Value>

Optional additional data from server



Validation

Validation errors (config, arguments, schema)

Fields

code: i32

Error code

message: String

Human-readable error message

errors: Vec<String>

Validation error details



Config

Configuration errors (loading, saving, parsing)

Fields

code: i32

Error code

message: String

Human-readable error message

source: Option<Box<dyn Error + Send + Sync>>

Optional source error



Io

IO errors

Fields

code: i32

Error code

message: String

Human-readable error message

source: Error

Source IO error



Serialization

Serialization/deserialization errors

Fields

code: i32

Error code

message: String

Human-readable error message

source: Error

Source error



Lifecycle

Lifecycle management errors

Fields

code: i32

Error code

message: String

Human-readable error message

server_name: Option<String>

Server name if applicable



Tool

Tool execution errors

Fields

code: i32

Error code

message: String

Human-readable error message

tool_name: Option<String>

Tool name



PermissionDenied

Permission denied errors

Fields

code: i32

Error code

message: String

Human-readable error message

tool_name: Option<String>

Tool name if applicable

Implementations

Source

impl McpError

pub fn code(&self) -> i32

Returns the error code

pub fn message(&self) -> &str

Returns the error message

pub fn connection(message: impl Into<String>) -> Self

Create a connection error

pub fn connection_with_source( message: impl Into<String>, source: impl Error + Send + Sync + 'static, ) -> Self

Create a connection error with source

pub fn transport(message: impl Into<String>) -> Self

Create a transport error

pub fn transport_with_source( message: impl Into<String>, source: impl Error + Send + Sync + 'static, ) -> Self

Create a transport error with source

pub fn protocol(message: impl Into<String>) -> Self

Create a protocol error

pub fn timeout(message: impl Into<String>, duration: Duration) -> Self

Create a timeout error

pub fn cancelled(message: impl Into<String>, reason: Option<String>) -> Self

Create a cancelled error

pub fn server( code: i32, message: impl Into<String>, data: Option<Value>, ) -> Self

Create a server error

pub fn validation(message: impl Into<String>, errors: Vec<String>) -> Self

Create a validation error

pub fn config(message: impl Into<String>) -> Self

Create a config error

pub fn config_with_source( message: impl Into<String>, source: impl Error + Send + Sync + 'static, ) -> Self

Create a config error with source

pub fn lifecycle( message: impl Into<String>, server_name: Option<String>, ) -> Self

Create a lifecycle error

pub fn tool(message: impl Into<String>, tool_name: Option<String>) -> Self

Create a tool error

pub fn permission_denied(message: impl Into<String>) -> Self

Create a permission denied error

pub fn permission_denied_for_tool( message: impl Into<String>, tool_name: impl Into<String>, ) -> Self

Create a permission denied error with tool name