render_inline_once

Function render_inline_once 

pub fn render_inline_once<T: Serialize>(
    template_str: &str,
    context_data: &T,
) -> Result<String, Error>
Renders a one-off ephemeral template (inline string).

This does not store anything in the global environment and is best for extension prompts or user-supplied templates that are used infrequently.

Arguments

  • template_str - The raw template string.
  • context_data - Data to be inserted into the template (must be Serialize).