Module base

Module base 

Structs

ConfigKey
Configuration key metadata for provider setup
ModelInfo
Information about a model’s capabilities
ProviderMetadata
Metadata about a provider’s configuration requirements and capabilities
ProviderUsage
Usage

Enums

ProviderType

Statics

CURRENT_MODEL
A global store for the current model being used, we use this as when a provider returns, it tells us the real model, not an alias
MSG_COUNT_FOR_SESSION_NAME_GENERATION

Traits

LeadWorkerProviderTrait
Trait for LeadWorkerProvider-specific functionality
Provider
Base trait for AI providers (OpenAI, Anthropic, etc)

Functions

get_current_model
Get the current model from the global store, the real model, not an alias
set_current_model
Set the current model in the global store
stream_from_single_message

Type Aliases

MessageStream
A message stream yields partial text content but complete tool calls, all within the Message object So a message with text will contain potentially just a word of a longer response, but tool calls messages will only be yielded once concatenated.