pub struct ProviderMetadata {
pub name: String,
pub display_name: String,
pub description: String,
pub default_model: String,
pub known_models: Vec<ModelInfo>,
pub model_doc_link: String,
pub config_keys: Vec<ConfigKey>,
}Expand description
Metadata about a provider’s configuration requirements and capabilities
Fields
name: StringThe unique identifier for this provider
display_name: StringDisplay name for the provider in UIs
description: StringDescription of the provider’s capabilities
default_model: StringThe default/recommended model for this provider
known_models: Vec<ModelInfo>A list of currently known models with their capabilities
model_doc_link: StringLink to the docs where models can be found
config_keys: Vec<ConfigKey>Required configuration keys
Implementations
Sourceimpl ProviderMetadata
impl ProviderMetadata
pub fn new( name: &str, display_name: &str, description: &str, default_model: &str, model_names: Vec<&str>, model_doc_link: &str, config_keys: Vec<ConfigKey>, ) -> Self
pub fn with_models( name: &str, display_name: &str, description: &str, default_model: &str, models: Vec<ModelInfo>, model_doc_link: &str, config_keys: Vec<ConfigKey>, ) -> Self
pub fn empty() -> Self