pub enum RecipeParameterInputType {
String,
Number,
Boolean,
Date,
File,
Select,
}Variants
String
Number
Boolean
Date
File
File parameter that imports content from a file path. Cannot have default values to prevent importing sensitive user files.
Select