pub struct ExtensionData {
pub extension_states: HashMap<String, Value>,
}Expand description
Extension data containing all extension states Keys are in format “extension_name.version” (e.g., “todo.v0”)
Fields
extension_states: HashMap<String, Value>Implementations
Sourceimpl ExtensionData
impl ExtensionData
Sourcepub fn get_extension_state(
&self,
extension_name: &str,
version: &str,
) -> Option<&Value>
pub fn get_extension_state( &self, extension_name: &str, version: &str, ) -> Option<&Value>
Get extension state for a specific extension and version
Sourcepub fn set_extension_state(
&mut self,
extension_name: &str,
version: &str,
state: Value,
)
pub fn set_extension_state( &mut self, extension_name: &str, version: &str, state: Value, )
Set extension state for a specific extension and version