pub struct ToolInspectionManager { /* private fields */ }Expand description
Manages all tool inspectors and coordinates their results
Implementations
Sourceimpl ToolInspectionManager
impl ToolInspectionManager
pub fn new() -> Self
Sourcepub fn add_inspector(&mut self, inspector: Box<dyn ToolInspector>)
pub fn add_inspector(&mut self, inspector: Box<dyn ToolInspector>)
Add an inspector to the manager Inspectors run in the order they are added
Sourcepub async fn inspect_tools(
&self,
tool_requests: &[ToolRequest],
messages: &[Message],
) -> Result<Vec<InspectionResult>>
pub async fn inspect_tools( &self, tool_requests: &[ToolRequest], messages: &[Message], ) -> Result<Vec<InspectionResult>>
Run all inspectors on the tool requests
Sourcepub fn inspector_names(&self) -> Vec<&'static str>
pub fn inspector_names(&self) -> Vec<&'static str>
Get list of registered inspector names
Sourcepub async fn update_permission_inspector_mode(&self, mode: AsterMode)
pub async fn update_permission_inspector_mode(&self, mode: AsterMode)
Update the permission inspector’s mode
Sourcepub async fn update_permission_manager(
&self,
tool_name: &str,
permission_level: PermissionLevel,
)
pub async fn update_permission_manager( &self, tool_name: &str, permission_level: PermissionLevel, )
Update the permission manager for a specific tool
Sourcepub fn get_integrated_permission_manager(
&self,
) -> Option<Arc<Mutex<IntegratedPermissionManager>>>
pub fn get_integrated_permission_manager( &self, ) -> Option<Arc<Mutex<IntegratedPermissionManager>>>
Get the integrated permission manager from the permission inspector
Returns the integrated permission manager if the permission inspector has been configured with one.
Requirements: 11.1, 11.4
Sourcepub fn process_inspection_results_with_permission_inspector(
&self,
remaining_requests: &[ToolRequest],
inspection_results: &[InspectionResult],
) -> Option<PermissionCheckResult>
pub fn process_inspection_results_with_permission_inspector( &self, remaining_requests: &[ToolRequest], inspection_results: &[InspectionResult], ) -> Option<PermissionCheckResult>
Process inspection results using the permission inspector This delegates to the permission inspector’s process_inspection_results method