pub struct Message {
pub id: Option<String>,
pub role: Role,
pub created: i64,
pub content: Vec<MessageContent>,
pub metadata: MessageMetadata,
}Expand description
A message to or from an LLM
Fields
id: Option<String>role: Rolecreated: i64content: Vec<MessageContent>metadata: MessageMetadataImplementations
Sourceimpl Message
impl Message
pub fn new(role: Role, created: i64, content: Vec<MessageContent>) -> Self
pub fn debug(&self) -> String
pub fn with_id<S: Into<String>>(self, id: S) -> Self
Sourcepub fn with_content(self, content: MessageContent) -> Self
pub fn with_content(self, content: MessageContent) -> Self
Add any MessageContent to the message
Sourcepub fn with_image<S: Into<String>, T: Into<String>>(
self,
data: S,
mime_type: T,
) -> Self
pub fn with_image<S: Into<String>, T: Into<String>>( self, data: S, mime_type: T, ) -> Self
Add image content to the message
Sourcepub fn with_tool_request<S: Into<String>>(
self,
id: S,
tool_call: ToolResult<CallToolRequestParam>,
) -> Self
pub fn with_tool_request<S: Into<String>>( self, id: S, tool_call: ToolResult<CallToolRequestParam>, ) -> Self
Add a tool request to the message
pub fn with_tool_request_with_metadata<S: Into<String>>( self, id: S, tool_call: ToolResult<CallToolRequestParam>, metadata: Option<&ProviderMetadata>, tool_meta: Option<Value>, ) -> Self
Sourcepub fn with_tool_response<S: Into<String>>(
self,
id: S,
result: ToolResult<CallToolResult>,
) -> Self
pub fn with_tool_response<S: Into<String>>( self, id: S, result: ToolResult<CallToolResult>, ) -> Self
Add a tool response to the message
pub fn with_tool_response_with_metadata<S: Into<String>>( self, id: S, result: ToolResult<CallToolResult>, metadata: Option<&ProviderMetadata>, ) -> Self
Sourcepub fn with_action_required<S: Into<String>>(
self,
id: S,
tool_name: String,
arguments: JsonObject,
prompt: Option<String>,
) -> Self
pub fn with_action_required<S: Into<String>>( self, id: S, tool_name: String, arguments: JsonObject, prompt: Option<String>, ) -> Self
Add an action required message for tool confirmation
pub fn with_frontend_tool_request<S: Into<String>>( self, id: S, tool_call: ToolResult<CallToolRequestParam>, ) -> Self
Sourcepub fn with_thinking<S1: Into<String>, S2: Into<String>>(
self,
thinking: S1,
signature: S2,
) -> Self
pub fn with_thinking<S1: Into<String>, S2: Into<String>>( self, thinking: S1, signature: S2, ) -> Self
Add thinking content to the message
Sourcepub fn with_redacted_thinking<S: Into<String>>(self, data: S) -> Self
pub fn with_redacted_thinking<S: Into<String>>(self, data: S) -> Self
Add redacted thinking content to the message
Sourcepub fn as_concat_text(&self) -> String
pub fn as_concat_text(&self) -> String
Get the concatenated text content of the message, separated by newlines
Sourcepub fn is_tool_call(&self) -> bool
pub fn is_tool_call(&self) -> bool
Check if the message is a tool call
Sourcepub fn is_tool_response(&self) -> bool
pub fn is_tool_response(&self) -> bool
Check if the message is a tool response
Sourcepub fn get_tool_ids(&self) -> HashSet<&str>
pub fn get_tool_ids(&self) -> HashSet<&str>
Retrieves all tool id from the message
Sourcepub fn get_tool_request_ids(&self) -> HashSet<&str>
pub fn get_tool_request_ids(&self) -> HashSet<&str>
Retrieves all tool id from ToolRequest messages
Sourcepub fn get_tool_response_ids(&self) -> HashSet<&str>
pub fn get_tool_response_ids(&self) -> HashSet<&str>
Retrieves all tool id from ToolResponse messages
Sourcepub fn has_only_text_content(&self) -> bool
pub fn has_only_text_content(&self) -> bool
Check if the message has only TextContent
pub fn with_system_notification<S: Into<String>>( self, notification_type: SystemNotificationType, msg: S, ) -> Self
Sourcepub fn with_visibility(self, user_visible: bool, agent_visible: bool) -> Self
pub fn with_visibility(self, user_visible: bool, agent_visible: bool) -> Self
Set the visibility metadata for the message
Sourcepub fn with_metadata(self, metadata: MessageMetadata) -> Self
pub fn with_metadata(self, metadata: MessageMetadata) -> Self
Set the entire metadata for the message
Sourcepub fn agent_only(self) -> Self
pub fn agent_only(self) -> Self
Mark the message as only visible to the agent (not the user)
Sourcepub fn is_user_visible(&self) -> bool
pub fn is_user_visible(&self) -> bool
Check if the message is visible to the user
Sourcepub fn is_agent_visible(&self) -> bool
pub fn is_agent_visible(&self) -> bool
Check if the message is visible to the agent