Structs
- Config
Key - Configuration key metadata for provider setup
- Model
Info - Information about a model’s capabilities
- Provider
Metadata - Metadata about a provider’s configuration requirements and capabilities
- Provider
Usage - Usage
Enums
Statics
- CURRENT_
MODEL - A global store for the current model being used, we use this as when a provider returns, it tells us the real model, not an alias
- MSG_
COUNT_ FOR_ SESSION_ NAME_ GENERATION
Traits
- Lead
Worker Provider Trait - Trait for LeadWorkerProvider-specific functionality
- Provider
- Base trait for AI providers (OpenAI, Anthropic, etc)
Functions
- get_
current_ model - Get the current model from the global store, the real model, not an alias
- set_
current_ model - Set the current model in the global store
- stream_
from_ single_ message
Type Aliases
- Message
Stream - A message stream yields partial text content but complete tool calls, all within the Message object So a message with text will contain potentially just a word of a longer response, but tool calls messages will only be yielded once concatenated.